/* 
potEVAP_to_actEVAP.c
calculation of actual soil evaporation from potential soil evaporation regarding to dry day limit (Joe Ritchie, 1970)

*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*
Biome-BGCMuSo v6.0.
Copyright 2019, D. Hidy [dori.hidy@gmail.com]
Hungarian Academy of Sciences, Hungary
See the website of Biome-BGCMuSo at http://nimbus.elte.hu/bbgc/ for documentation, model executable and example input files.
*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*
*/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <math.h>
#include <malloc.h>
#include "ini.h"
#include "bgc_struct.h"
#include "bgc_constants.h"
#include "bgc_func.h"    

int potEVAP_to_actEVAP(const control_struct* ctrl, const soilprop_struct* sprop, epvar_struct* epv, wstate_struct* ws, wflux_struct* wf)
{

	/* internal variables */
	int errflag=0;
	double infilt_ratio;
	
	/* precipitation is the sum of different water fluxes */
	wf->pot_infilt = (wf->prcp_to_soilw + wf->snoww_to_soilw + wf->canopyw_to_soilw + wf->IRG_to_prcp + ws->pond_water);


	/* calculation of drs parameter, the limitation of soil evaporation - Joe Ritchie (1970) */
	infilt_ratio = 0.8;

	/* first evaporation phase - no limit */
	if (ws->soil_evapCUM1 < sprop->soilevapLIM)
	{
		epv->dsr = 0;
	
		if (wf->pot_infilt >= ws->soil_evapCUM1)
		{
			ws->soil_evapCUM1 = 0;
		}
		else
		{
			ws->soil_evapCUM1 -= wf->pot_infilt;
		}
		
		if (!errflag && evapPHASE1toPHASE2(sprop, epv, ws, wf))
		{
			printf("\n");
			printf("ERROR in evapPHASE1toPHASE2() in POTevap_to_actEVAP.c\n");
			errflag=1; 
		} 

	}
	/* ws->soil_evapCUM1 > soilevapLIM: second evaporation phase - limit of dsr */
	else
	{
		if (wf->pot_infilt >= ws->soil_evapCUM2) 
		{
			epv->dsr = 0;

			/* berszivrg csapadk feltlt CUM2-t, a maradk meg a CUM1-bl amennyit csak tud */
			wf->pot_infilt             -= ws->soil_evapCUM2;
			ws->soil_evapCUM2   =0;

			if (wf->pot_infilt > sprop->soilevapLIM)
				ws->soil_evapCUM1  = 0;
			else
				ws->soil_evapCUM1  -= wf->pot_infilt;

			if (!errflag && evapPHASE1toPHASE2(sprop, epv, ws, wf))
			{
				printf("\n");
				printf("ERROR in evapPHASE1toPHASE2() in POTevap_to_actEVAP.c\n");
				errflag=1; 
			} 
		}
		else
		{
			epv->dsr += 1;
			wf->soilw_evap = 3.5 * pow(epv->dsr, 0.5) - ws->soil_evapCUM2;

			if (infilt_ratio * wf->pot_infilt <= wf->soilw_evap) wf->soilw_evap += wf->pot_infilt;
			if (infilt_ratio * wf->pot_infilt > wf->pot_evap) wf->soilw_evap = wf->pot_evap;
			if (wf->soilw_evap  > wf->pot_evap) wf->soilw_evap = wf->pot_evap; 

			ws->soil_evapCUM2 += wf->soilw_evap - wf->pot_infilt;
			epv->dsr = pow((ws->soil_evapCUM2/3.5),2); 
		}
	}


	/* control */
	if (wf->soilw_evap < 0 && epv->dsr < 0)
	{
		errflag=1;
	}
	return (errflag);
}

int evapPHASE1toPHASE2(const soilprop_struct* sprop, epvar_struct* epv, wstate_struct* ws, wflux_struct* wf)
{
	/* internal variables */
	int errflag=0;

	
	if (ws->soil_evapCUM1 > sprop->soilevapLIM)
	{
		wf->soilw_evap = wf->pot_evap - 0.4*(ws->soil_evapCUM1 - sprop->soilevapLIM);
		ws->soil_evapCUM2 = 0.6*(ws->soil_evapCUM1 - sprop->soilevapLIM);
		epv->dsr = pow(ws->soil_evapCUM2/3.5,2);
		ws->soil_evapCUM1 = sprop->soilevapLIM;
	}
	else
	{
		wf->soilw_evap = wf->pot_evap; 
		ws->soil_evapCUM1 += wf->pot_evap;
	}

	if (ws->soil_evapCUM1 > sprop->soilevapLIM)
	{
		ws->soil_evapCUM2 += ws->soil_evapCUM1 - sprop->soilevapLIM;
		ws->soil_evapCUM1  = sprop->soilevapLIM;
	}

     

return (errflag);
}