/* 
soilstress_calculation.c
calculation of drought and saturation soil water content stress layer by layers 

*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*
Biome-BGCMuSo v6.0.
Copyright 2019, D. Hidy [dori.hidy@gmail.com]
Hungarian Academy of Sciences, Hungary
See the website of Biome-BGCMuSo at http://nimbus.elte.hu/bbgc/ for documentation, model executable and example input files.
*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*
*/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <math.h>
#include <malloc.h>
#include "ini.h"
#include "bgc_struct.h"
#include "bgc_constants.h"
#include "bgc_func.h"    

int soilstress_calculation(const soilprop_struct* sprop, const epconst_struct* epc, epvar_struct* epv)
{
	int layer;
	double m_vwcR_layer, m_soilstress_avg;

	int errflag = 0;
	m_soilstress_avg = 0;
	
	/* soilstress can occur only after emergence */
	if (epv->n_actphen > epc->n_emerg_phenophase)
	{
		for (layer = 0; layer < N_SOILLAYERS; layer++)
		{
			m_vwcR_layer = 1;

			if (epv->vwc[layer] > sprop->vwc_wp[layer] && (sprop->vwc_sat[layer] - epv->vwc[layer]) > CRIT_PREC)
			{
				/* DROUGHT STRESS */
				if (epv->vwc[layer] <= epv->vwc_crit1[layer])
				{
						m_vwcR_layer  = 1 - (epv->vwc_crit1[layer] - epv->vwc[layer])/(epv->vwc_crit1[layer] - sprop->vwc_wp[layer]);
				}

				/* ANOXIC CONDITION STRESS */
				if (epv->vwc[layer] >= epv->vwc_crit2[layer])
				{
					m_vwcR_layer  = (sprop->vwc_sat[layer] - epv->vwc[layer])/(sprop->vwc_sat[layer] - epv->vwc_crit2[layer]);	
				}
			}
			else
				m_vwcR_layer  = 0;

			/* lower limit for saturation: m_fullstress2 */
			if (epv->vwc[layer] >= epv->vwc_crit1[layer] && m_vwcR_layer < epc->m_fullstress2) m_vwcR_layer = epc->m_fullstress2;

			/* if VWCratio_crit is set to -9999: no soilstress calculation -> m_soilstress = 1 */
			if (epc->VWCratio_crit1 == DATA_GAP && epv->vwc[layer] <= sprop->vwc_fc[layer]) m_vwcR_layer  = 1;
			if (epc->VWCratio_crit2 == DATA_GAP && epv->vwc[layer] >= sprop->vwc_fc[layer]) m_vwcR_layer  = 1;

			epv->m_soilstress_layer[layer] =  m_vwcR_layer;
			m_soilstress_avg	 += epv->m_soilstress_layer[layer] * epv->rootlength_prop[layer];
		}
	
		epv->m_soilstress = m_soilstress_avg;
}

	return (errflag);
}